sievetools
==========

.. automodule:: abjad.tools.sievetools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.sievetools.BaseResidueClass.BaseResidueClass
      ~abjad.tools.sievetools.ResidueClass.ResidueClass
      ~abjad.tools.sievetools.Sieve.Sieve
